==> ejc-zdkcg-impl-3.0.0-20210426.032340-17-sources.jar: com/ejianc/business/zdkcg/bean/WebsiteHelpEntity.java <==
package com.ejianc.business.zdkcg.bean;

import java.util.Date;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 帮助中心
 * 
 * @author liyj
 * 
 */
 @TableName("ejc_zdkwebsite_help")
public class WebsiteHelpEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

	/**
	 * 版本
	 */
    @TableField(value="edition")
    private String edition;

	/**
	 * 标题
	 */
    @TableField(value="title")
    private String title;

	/**
	 * 试用区域
	 */
    @TableField(value="trial_area")
    private String trialArea;

	/**
	 * 状态(1启用，0停用)
	 */
    @TableField(value="state")
    private String state;

	/**
	 * 发布人
	 */
    @TableField(value="publisher")
    private String publisher;

	/**
	 * 发布时间
	 */
	@TableField(value = "publish_time")
	private Date publishTime;

	@TableField(value = "org_id")
	private Long orgId; // 发布组织ID

	@TableField(value = "publish_flag")
	private Integer publishFlag; // 是否发布 ， 1：发布 ， 0：未发布

	@TableField(value = "top_flag")
	private Integer topFlag; // 是否置顶, 1:置顶 ， 0： 取消置顶

	/**
	 * 说明
	 */
    @TableField(value="explanation")
    private String explanation;

	/**
	 * 文件大小
	 */
    @TableField(value="file_size")
    private String fileSize;

	/**
	 * 类型：tool:工具软件,operateVideo:操作视频,operateGuide:操作指引
	 */
    @TableField(value="type")
    private String type;

	public String getEdition() {
		return edition;
	}

	public void setEdition(String edition) {
		this.edition = edition;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getTrialArea() {
		return trialArea;
	}

	public void setTrialArea(String trialArea) {
		this.trialArea = trialArea;
	}

	public String getState() {
		return state;
	}

	public void setState(String state) {
		this.state = state;
	}

	public String getPublisher() {
		return publisher;
	}

	public void setPublisher(String publisher) {
		this.publisher = publisher;
	}

	public String getExplanation() {
		return explanation;
	}

	public void setExplanation(String explanation) {
		this.explanation = explanation;
	}

	public String getFileSize() {
		return fileSize;
	}

	public void setFileSize(String fileSize) {
		this.fileSize = fileSize;
	}

	public Date getPublishTime() {
		return publishTime;
	}

	public void setPublishTime(Date publishTime) {
		this.publishTime = publishTime;
	}

	public Long getOrgId() {
		return orgId;
	}

	public void setOrgId(Long orgId) {
		this.orgId = orgId;
	}

	public Integer getPublishFlag() {
		return publishFlag;
	}

	public void setPublishFlag(Integer publishFlag) {
		this.publishFlag = publishFlag;
	}

	public Integer getTopFlag() {
		return topFlag;
	}

	public void setTopFlag(Integer topFlag) {
		this.topFlag = topFlag;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

}

==> ejc-zdkcg-impl-3.0.0-20210427.073614-24-sources.jar: com/ejianc/business/zdkcg/bean/WebsiteHelpEntity.java <==
package com.ejianc.business.zdkcg.bean;

import java.util.Date;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 帮助中心
 * 
 * @author liyj
 * 
 */
 @TableName("ejc_zdkwebsite_help")
public class WebsiteHelpEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

	/**
	 * 版本
	 */
    @TableField(value="edition")
    private String edition;

	/**
	 * 标题
	 */
    @TableField(value="title")
    private String title;

	/**
	 * 试用区域
	 */
    @TableField(value="trial_area")
    private String trialArea;

	/**
	 * 状态(1启用，0停用)
	 */
    @TableField(value="state")
    private String state;

	/**
	 * 发布人
	 */
    @TableField(value="publisher")
    private String publisher;

	/**
	 * 发布时间
	 */
	@TableField(value = "publish_time")
	private Date publishTime;

	@TableField(value = "org_id")
	private Long orgId; // 发布组织ID

	@TableField(value = "publish_flag")
	private Integer publishFlag; // 是否发布 ， 1：发布 ， 0：未发布

	@TableField(value = "top_flag")
	private Integer topFlag; // 是否置顶, 1:置顶 ， 0： 取消置顶

	/**
	 * 说明
	 */
    @TableField(value="explanation")
    private String explanation;

	/**
	 * 文件大小
	 */
    @TableField(value="file_size")
    private String fileSize;

	/**
	 * 文件名称
	 */
    @TableField(value="file_name")
    private String fileName;

	/**
	 * 文件地址
	 */
    @TableField(value="file_path")
    private String filePath;

	/**
	 * 文件
	 */
    @TableField(value="file")
    private String file;

	/**
	 * 类型：tool:工具软件,operateVideo:操作视频,operateGuide:操作指引
	 */
    @TableField(value="type")
    private String type;

	public String getEdition() {
		return edition;
	}

	public void setEdition(String edition) {
		this.edition = edition;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getTrialArea() {
		return trialArea;
	}

	public void setTrialArea(String trialArea) {
		this.trialArea = trialArea;
	}

	public String getState() {
		return state;
	}

	public void setState(String state) {
		this.state = state;
	}

	public String getPublisher() {
		return publisher;
	}

	public void setPublisher(String publisher) {
		this.publisher = publisher;
	}

	public String getExplanation() {
		return explanation;
	}

	public void setExplanation(String explanation) {
		this.explanation = explanation;
	}

	public String getFileSize() {
		return fileSize;
	}

	public void setFileSize(String fileSize) {
		this.fileSize = fileSize;
	}

	public Date getPublishTime() {
		return publishTime;
	}

	public void setPublishTime(Date publishTime) {
		this.publishTime = publishTime;
	}

	public Long getOrgId() {
		return orgId;
	}

	public void setOrgId(Long orgId) {
		this.orgId = orgId;
	}

	public Integer getPublishFlag() {
		return publishFlag;
	}

	public void setPublishFlag(Integer publishFlag) {
		this.publishFlag = publishFlag;
	}

	public Integer getTopFlag() {
		return topFlag;
	}

	public void setTopFlag(Integer topFlag) {
		this.topFlag = topFlag;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public String getFile() {
		return file;
	}

	public void setFile(String file) {
		this.file = file;
	}

	public String getFileName() {
		return fileName;
	}

	public void setFileName(String fileName) {
		this.fileName = fileName;
	}

	public String getFilePath() {
		return filePath;
	}

	public void setFilePath(String filePath) {
		this.filePath = filePath;
	}

}
